@@ -4,10 +4,12 @@
 # - Patent
 # - Praca_Doktorska
 # - Praca_Habilitacyjna
+
 import denorm
 from django.db import connections, models, router
 from django.db.models import CASCADE, ForeignKey
 from django.db.models.deletion import DO_NOTHING
+from django.urls import reverse
 from taggit.managers import TaggableManager, _TaggableManager
 from taggit.models import Tag
 
@@ -380,6 +382,10 @@ class RekordBase(
     def js_safe_pk(self):
         return "%i_%i" % (self.pk[0], self.pk[1])
 
+    @cached_property
+    def form_post_pk(self):
+        return "{%i,%i}" % (self.pk[0], self.pk[1])
+
     @cached_property
     def ma_punktacje_sloty(self):
         return (
@@ -409,6 +415,21 @@ class RekordBase(
     def punktacja_autora(self):
         return Cache_Punktacja_Autora.objects.filter(rekord_id=[self.id[0], self.id[1]])
 
+    @cached_property
+    def pierwszy_autor_afiliowany(self):
+        """Zwraca pierwszego autora, afiliującego na jednostkę uczelni z tej pracy"""
+        return self.autorzy.filter(afiliuje=True).order_by("kolejnosc").first()
+
+    @cached_property
+    def pierwsza_jednostka_afiliowana(self):
+        """Zwraca pierwszego autora, afiliującego na jednostkę uczelni z tej pracy"""
+        res = self.pierwszy_autor_afiliowany()
+        if res is not None:
+            return self.pierwszy_autor_afiliowany().jednostka
+
+    def get_absolute_url(self):
+        return reverse("bpp:browse_rekord", args=(self.pk[0], self.pk[1]))
+
 
 class Rekord(RekordBase):
     class Meta:
