@@ -1,3 +1,4 @@
+from django.db.models import Case, Q, TextField, When
 from multiseek.logic import Ordering, create_registry
 
 from .fields import *  # noqa
@@ -27,12 +28,31 @@ registry = create_registry(
 )
 
 
+def _get_default_queryset_for_model():
+    return Rekord.objects.all().annotate(
+        zrodlo_lub_nadrzedne=Case(
+            When(
+                Q(zrodlo_id=None),
+                then="wydawnictwo_nadrzedne__tytul_oryginalny",
+            ),
+            When(
+                Q(wydawnictwo_nadrzedne_id=None),
+                then="zrodlo__nazwa",
+            ),
+            output_field=TextField(),
+        )
+    )
+
+
+registry.get_default_queryset_for_model = _get_default_queryset_for_model
+
+
 def _get_fields(self, request):
     """Ta funkcja sortuje pola zgodnie z ustawieniem pola ui_order (czyli bazodanowy
     sort_order obiektu BppMultiseekVisibility) i zwraca je w kolejności.
     """
     return sorted(
-        [x for x in self.fields if x.enabled(request)], key=lambda x: x.ui_order
+        (x for x in self.fields if x.enabled(request)), key=lambda x: x.ui_order
     )
 
 
