@@ -1,8 +1,10 @@
-# -*- encoding: utf-8 -*-
-
 from django.test import TestCase
-from bpp.management.commands.look_for_unused_fields import Command as LookForUnusedFields
+
+from bpp.management.commands.look_for_unused_fields import (
+    Command as LookForUnusedFields,
+)
+
 
 class TestManagement(TestCase):
     def test_LookForUnusedFields(self):
-        LookForUnusedFields().handle(silent=True)
\ No newline at end of file
+        LookForUnusedFields().handle(silent=True)
