@@ -1,5 +1,3 @@
-# -*- encoding: utf-8 -*-
-
 # Konfiguracja hosta 'master'
 
 import os
@@ -14,6 +12,7 @@ SENDFILE_BACKEND = "sendfile.backends.simple"
 
 SELENIUM_DRIVER = "Firefox"
 
+
 SESSION_COOKIE_SECURE = False
 CSRF_COOKIE_SECURE = False
 MEDIA_ROOT = os.path.abspath(
@@ -37,3 +36,5 @@ CACHES = {
         "BACKEND": "django.core.cache.backends.dummy.DummyCache",
     }
 }
+
+PASSWORD_HASHERS = ["django.contrib.auth.hashers.MD5PasswordHasher"]
