@@ -1,6 +1,6 @@
 import pytest
 from django.core.files.base import File
-from model_mommy import mommy
+from model_bakery import baker
 
 from ewaluacja2021.models import ImportMaksymalnychSlotow
 from ewaluacja2021.tests.utils import curdir
@@ -10,7 +10,7 @@ from bpp.models import Dyscyplina_Naukowa
 
 @pytest.mark.django_db
 def test_ImportMaksymalnychSlotow_analizuj(autor_jan_kowalski):
-    mommy.make(Dyscyplina_Naukowa, nazwa="nauki farmaceutyczne")
+    baker.make(Dyscyplina_Naukowa, nazwa="nauki farmaceutyczne")
 
     ims = ImportMaksymalnychSlotow.objects.create()
     ims.plik.save("test.xlsx", File(open(curdir("test_file.xlsx", __file__), "rb")))
