@@ -2,7 +2,7 @@ from datetime import date
 
 from django.core.serializers.json import DjangoJSONEncoder
 from django.db import IntegrityError, models, transaction
-from django.db.models import CASCADE, Count, Q
+from django.db.models import CASCADE, Count, JSONField, Q
 from django.urls import reverse
 from django_fsm import GET_STATE, FSMField, transition
 from model_utils.models import TimeStampedModel
@@ -14,8 +14,6 @@ from import_common.exceptions import (
 )
 from import_common.util import znajdz_naglowek
 
-from django.contrib.postgres.fields import JSONField
-
 from bpp.fields import YearField
 from bpp.models import Autor, Autor_Dyscyplina, Dyscyplina_Naukowa, Jednostka, Wydzial
 
@@ -498,7 +496,7 @@ class Import_Dyscyplin(TimeStampedModel):
 
     def delete(self, *args, **kw):
         transaction.on_commit(lambda instance=self: instance.plik.delete(False))
-        return super(Import_Dyscyplin, self).delete(*args, **kw)
+        return super().delete(*args, **kw)
 
     class Meta:
         ordering = ("-modified",)
@@ -533,8 +531,10 @@ class Import_Dyscyplin_Row(models.Model):
     nazwa_wydzialu = models.CharField(max_length=512, blank=True, null=True)
     wydzial = models.ForeignKey(Wydzial, null=True, on_delete=models.SET_NULL)
 
-    dyscyplina = models.CharField(max_length=200, db_index=True)
-    kod_dyscypliny = models.CharField(max_length=20, db_index=True)
+    dyscyplina = models.CharField(max_length=200, db_index=True, blank=True, null=True)
+    kod_dyscypliny = models.CharField(
+        max_length=20, db_index=True, blank=True, null=True
+    )
     procent_dyscypliny = models.DecimalField(
         max_digits=5, decimal_places=2, null=True, blank=True
     )
@@ -583,7 +583,7 @@ class Import_Dyscyplin_Row(models.Model):
 
         if self.autor is not None:
             ret["autor_slug"] = self.autor.slug
-            ret["dopasowanie_autora"] = "<a target=_blank href='%s'>%s %s</a>" % (
+            ret["dopasowanie_autora"] = "<a target=_blank href='{}'>{} {}</a>".format(
                 reverse("bpp:browse_autor", args=(self.autor.slug,)),
                 self.autor.nazwisko,
                 self.autor.imiona,
