@@ -1,16 +1,29 @@
 import pytest
-from django.contrib.contenttypes.models import ContentType
 from flexible_reports.models import Column, Datasource, Report, ReportElement, Table
-from model_mommy import mommy
+from model_bakery import baker
 
+from django.contrib.auth.models import Group
+from django.contrib.contenttypes.models import ContentType
+
+from bpp.const import GR_RAPORTY_WYSWIETLANIE
 from bpp.models import Wydawnictwo_Zwarte
 
 
 @pytest.fixture
-def raport_autorow(db):
-    table = mommy.make(Table)
+def generuj_raporty_app(app, normal_django_user):
+    # To samo co ``app`` czyli aplikacja WebTest z zalogowanym ``normal_django_user``
+    # ale użytkownik ma grupę "generuj raporty":
+    normal_django_user.groups.add(
+        Group.objects.get_or_create(name=GR_RAPORTY_WYSWIETLANIE)[0]
+    )
+    return app
 
-    mommy.make(Column, parent=table)
+
+@pytest.fixture
+def raport_autorow(db):
+    table = baker.make(Table)
+
+    baker.make(Column, parent=table)
 
     ds = Datasource.objects.create(
         base_model=ContentType.objects.get_for_model(Wydawnictwo_Zwarte),
