@@ -1,9 +1,8 @@
 from django.db import models
+from django.db.models import JSONField
 
 from .base import BasePBNModel
 
-from django.contrib.postgres.fields import JSONField
-
 
 class Language(BasePBNModel):
     code = models.CharField(max_length=5, primary_key=True)
