@@ -3,6 +3,7 @@ import traceback
 from contextlib import redirect_stderr, redirect_stdout
 
 from django.core.management import ManagementUtility
+from sentry_sdk import capture_exception
 
 from tee.models import Log
 from tee.utils import TeeIO
@@ -22,6 +23,9 @@ def execute(argv, **kwargs):
 
     log = Log.objects.create(command_name=argv[0], args=argv[1:])
 
+    # TODO: this is memory-inefficient. stdout or stderr should flush from time to time
+    # and save the result to the database, like in 1-MB chunks
+
     try:
         with redirect_stderr(stderr):
             with redirect_stdout(stdout):
@@ -29,7 +33,9 @@ def execute(argv, **kwargs):
                     utility = ManagementUtility(argv)
                     utility.execute()
                     log.finished_successfully = True
-                except Exception:
+                except Exception as e:
+                    capture_exception(e)
+
                     log.finished_successfully = False
                     log.traceback = traceback.format_exc(limit=65535)
 
