@@ -1,12 +1,11 @@
 from django.db import models
-
-from django.contrib.postgres.fields import JSONField
+from django.db.models import JSONField
 
 
 class Log(models.Model):
     started_on = models.DateTimeField(auto_now_add=True)
     finished_on = models.DateTimeField(blank=True, null=True)
-    finished_successfully = models.NullBooleanField()
+    finished_successfully = models.BooleanField(null=True, blank=True, default=None)
 
     command_name = models.TextField()
     args = JSONField(blank=True, null=True)
